<?xml version="1.0"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:graph="graph" xmlns:results="results" extension-element-prefixes="saxon">

    <!-- =================  print generation menu ============================ -->
    
    <xsl:template name="display_generation_menu">
	<xsl:param name="auth"/>
    
    <xsl:variable name="href" saxon:assignable="yes">#tg</xsl:variable>
    <xsl:if test="$auth">
    	<saxon:assign name="href" select="concat('#tgt_',$auth)"/>    	
    </xsl:if>
                      
	<xsl:if test="($generation) > 0">
    <xsl:call-template name="display_linked_menu_item">
  	 <xsl:with-param name="text" select="$RES_PARAMETER_TEST_GENERATION" />
     <xsl:with-param name="link" select="$href" />
    </xsl:call-template>
	</xsl:if>       
    </xsl:template>

    <!-- =================  print generation ============================ -->
    
    <xsl:template name="display_generation">
    
       <!-- print test generation header -->
       <xsl:if test="($generation) > 0">
          <br/>
          <xsl:call-template name="tg_header"/>
       </xsl:if>

       <!-- print test generation summary info -->
       <xsl:if test="($tg_projects_info_nmb) > 0">
          <br/>
          <xsl:call-template name="tg_summary_info"/>
    
          <xsl:if test="($report.authors_details) = 'true'">
             <br/>
             <xsl:if test="($tg_info_nmb) > 0">
                <xsl:call-template name="tg_authors_summary"/>
                <br/>
             </xsl:if>    
             <!-- print generation error details info for each auth -->
             <xsl:if test="($tg_info_nmb) > 0 and ($report.developer_errors) = 'true'">
                <table width='{$width}' border='0' bordercolor='{$exec_bcolor}' cellpadding='0' cellspacing='0'>
                   <xsl:if test="($report_format_mode='pdf')">
                      <xsl:attribute name="cols">80% 10% 10%</xsl:attribute>
                   </xsl:if>
                   <xsl:call-template name="tg_details_info"/>
                </table>
             </xsl:if>
          </xsl:if>
          
       </xsl:if>
    
       <!-- print test generation msg -->  
       <xsl:if test="($generation) > 0 and not(($tg_projects_info_nmb) > 0)">
          <br/>
          <!--a name="tg"></a-->
          <xsl:call-template name="checker_error">
             <xsl:with-param name="title"></xsl:with-param>
             <xsl:with-param name="msg"><xsl:value-of select="$RES_PARAMETER_NO_RESOURCES_FOUND"/></xsl:with-param>
             <xsl:with-param name="last_author"><xsl:value-of select="$RES_PARAMETER_UNKNOWN"/></xsl:with-param>
             <xsl:with-param name="color" select="($exec_bcolor)"/>
             <xsl:with-param name="bcolor" select="($exec_bdrcolor)"/>
             <xsl:with-param name="stdalone">false</xsl:with-param>
             <xsl:with-param name="failure">true</xsl:with-param>
          </xsl:call-template>
          <br/>
       </xsl:if>
          
    </xsl:template>    
    
    <!-- =================  print checker error ============================ -->
    
    <xsl:template name="checker_error">
    <xsl:param name="title"/>
    <xsl:param name="msg"/>
    <xsl:param name="last_author"/>
    <xsl:param name="color"/>
    <xsl:param name="bcolor"/>
    <xsl:param name="stdalone"/>
    <xsl:param name="failure"/>

    <table class="singleborder" width='{$width}' bordercolor='{$bcolor}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">30% 70%</xsl:attribute>
        </xsl:if>
    <xsl:if test="not(boolean($stdalone))">
    <tr>
    <td class="singleborder" align="left" colspan="2" bgcolor="{$color}" nowrap="nowrap">
    <b><xsl:value-of select="($title)"/></b>
    <a class="red_link" href="#top"> ^ </a>
    </td>
    </tr>
    </xsl:if>
    
    <xsl:if test="boolean($stdalone)">        
    <tr>
    <td class="singleborder" align="center" bgcolor="{$color}">
    <xsl:if test="not($failure = 'true')">
        <b><xsl:value-of select="$RES_PARAMETER_ERROR"/></b>
    </xsl:if>
    <xsl:if test="$failure = 'true'">
        <b><xsl:value-of select="$RES_PARAMETER_FAILURE"/></b>
    </xsl:if>
    </td>
    <td class="singleborder" align="center" bgcolor="{$color}">
        <b><xsl:value-of select="$RES_PARAMETER_AUTHOR"/></b>
    </td>
    </tr>
    </xsl:if>
    <tr>
    <td class="singleborder" align="center">
    <xsl:value-of select="($msg)"/>
    </td>
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($last_author)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </tr>
    <xsl:if test="not(boolean($stdalone))">
    <tr>
    <td class="singleborder" align="left" colspan="2" bgcolor="{$color}"><font class="small">-</font></td>
    </tr>
    </xsl:if>
    </table>
    </xsl:template>
    
    <!-- =================  print generation header ============================ -->
    
    <xsl:template name="tg_header">
    <xsl:param name="ref"/>
    <xsl:if test="not(string-length($ref) > 0)">
    <a name="tg"></a>
    </xsl:if>   
    <xsl:if test="string-length($ref) > 0">
    <a name="{$ref}"></a>
    </xsl:if>   
    <table width='{$width}' border='0' bordercolor='{$exec_bdrcolor}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">25% 50% 25%</xsl:attribute>
        </xsl:if>
    <tr>
    <td width="25%"></td>
    <td align="center">    
        <div class="header"><xsl:value-of select="$RES_PARAMETER_TEST_GENERATION"/></div>    
    </td>
    <td align="right" width="25%" valign="bottom">
	  	<xsl:if test="not($report_type = $email_report) and ($first_back_to_top = 'false')">
           <xsl:call-template name="back_to_top"/>
        </xsl:if>
   		<saxon:assign name="first_back_to_top">false</saxon:assign>
    </td>
    </tr>
    </table>
    </xsl:template>
  
    <!-- =================  print generation summary info ============================ -->
    
    <xsl:template name="tg_summary_info">
    <table width='{$width}' border='0' bordercolor="{$exec_bdrcolor}" cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
    <td>
    <table class="singleborder" width='100%' bordercolor="{$exec_bdrcolor}" cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">49% 17% 17% 17%</xsl:attribute>
        </xsl:if>
    <tr>
    <td class="singleborder" width="50%" align='center' bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_PROJECT_NAME"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
    <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_CHECKED_FILES"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
    <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_TEST_FILES"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
    <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_NEW_TEST_CASES"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
    </tr>
    <xsl:variable name="total_time" select="/ResultsSession/Generation/@time"/>
    <xsl:variable name="tfiles_checked" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="ttest_classes" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="ttest_cases" saxon:assignable="yes">0</xsl:variable>
    <xsl:for-each select="/ResultsSession/Generation/Projects/GenerationProjectInfo">
    <xsl:variable name="project_name" select="@project"/>   
    <tr>
    <!-- project name -->
    <td class="singleborder" align="left"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($project_name)"/></td>
    <!-- checked files -->
    <xsl:variable name="cfiles_checked" select="@filesChecked"/>
    <saxon:assign name="tfiles_checked" select="$tfiles_checked + $cfiles_checked"/>
    <td class="singleborder" align="right">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($cfiles_checked)"/> 
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <!-- tests classes -->
    <xsl:variable name="ctest_classes" select="@testCls"/>
    <saxon:assign name="ttest_classes" select="$ttest_classes + $ctest_classes"/>
    <td class="singleborder" align="right">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($ctest_classes)"/> 
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <!-- tests cases -->
    <xsl:variable name="ctest_cases" select="@testCases"/>
    <saxon:assign name="ttest_cases" select="$ttest_cases + $ctest_cases"/>
    <td class="singleborder" align="right">  
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($ctest_cases)"/> 
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </tr>
    </xsl:for-each>
    <tr>
    <td class="singleborder" align="left">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <b><xsl:value-of select="$RES_PARAMETER_TOTAL"/></b> [<xsl:value-of select="($total_time)"/>]
    </td>
      <!-- files checked -->
    <td class="singleborder" align="right">  
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <b>
    <xsl:value-of select="($tfiles_checked)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
      <!-- total test classes -->
    <td class="singleborder" align="right">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <b>
    <xsl:value-of select="($ttest_classes)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <!-- total test cases -->
    <td class="singleborder" align="right">  
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <b>
    <xsl:value-of select="($ttest_cases)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </tr>
    </table>
    </td>
    </tr>
    </table>
    </xsl:template>

    <!-- =================  print test generation auth info 2 ============================ -->
    
    <xsl:template name="tg_author_info_2">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    
    <xsl:variable name="author_cs_violations" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')])"/>
    <xsl:variable name="author_tcases" 
        select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)]/TestCaseList/TestCase)"/>
    <xsl:variable name="author_exec_violations" 
        select="count(/ResultsSession/Exec/ExecViols/ExecViol[@auth=($auth)])"/>
    <xsl:variable name="author_cs_supp" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and @supp='true'])"/>
    <xsl:variable name="enable_supp" saxon:assignable="yes">0</xsl:variable>
    <xsl:if test="($report.suppressed_msgs = 'true') and (($author_cs_supp) > 0)">
    <saxon:assign name="enable_supp">1</saxon:assign>
    </xsl:if>
       
    <tr>
    <td class="singleborder" align="left">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/> 
    
    <xsl:variable name="author_all_tasks" select="($author_cs_violations) + ($author_tcases) + ($author_exec_violations) + ($enable_supp)"/>
    
    <xsl:if test="($author_all_tasks) > 0">
    <xsl:if test="(($report.developer_reports) = 'true') and not(($report_type) = ($email_report))">
    <xsl:variable name="author_html" select="concat($dev_reports_prefix,$authid,'.html#tgt_',$authid)"/>
    <xsl:variable name="href" saxon:assignable="yes" select="concat('javascript:openWin(',$qt,$author_html,$qt,')')"/>
    <xsl:if test="($report_type) = ($tcm_report)">
       <xsl:variable name="dev_rep_name" select="concat($dev_reports_prefix,$authid,'.html')"/>
       <saxon:assign name="href" select="concat('javascript:openDevReport(',$qt,$dev_rep_name,$qt,')')"/>
    </xsl:if>
    <xsl:call-template name="standard_link_ref">
    <xsl:with-param name="href" select="($href)"/>
    <xsl:with-param name="label" select="($auth)"/>
    <xsl:with-param name="class">blue_link</xsl:with-param>
    </xsl:call-template>
    </xsl:if>
    <xsl:if test="(($report.developer_errors) = 'true') and ((($report.developer_reports) = 'false') or (($report_type) = ($email_report)))">
    <a class="blue_link" href="#tg_{$authid}"><xsl:value-of select="($auth)"/></a>
    </xsl:if>
    <xsl:if test="(($report.developer_errors) = 'false') and (($report.developer_reports = 'false') or (($report_type) = ($email_report)))">
    <font class="blue">
    <xsl:value-of select="($auth)"/>
    </font>
    </xsl:if>
        
    </xsl:if>
    <xsl:if test="not(($author_all_tasks) > 0)">
    <font class="blue">
    <xsl:value-of select="($auth)"/>
    </font>
    </xsl:if>
    </td>
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_tcases)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    </tr>
    </xsl:template>
    
    <!-- =================  print junit auth list info ============================ -->
    
    <xsl:template name="tg_author_list_info">    
        <xsl:for-each select="/ResultsSession/Authors/Author">
    
            <xsl:call-template name="tg_author_info_2">
                <xsl:with-param name="auth" select="@name"/>
                <xsl:with-param name="authid" select="@id"/>
            </xsl:call-template>

       </xsl:for-each> 
    </xsl:template>
    
    <!-- =================  tg_authors_summary ============================ -->
    
    <xsl:template name="tg_authors_summary">
    
    <xsl:call-template name="authors_header"/>
    <table class="singleborder" align="center" width='{$authors_width}' bordercolor='{$exec_bdrcolor}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">30% 70%</xsl:attribute>
        </xsl:if>
       <tr align="center"  bgcolor="{$exec_bcolor}">
       <td class="singleborder" width="50%" align="center">
           <b><xsl:value-of select="$RES_PARAMETER_AUTHOR"/></b>
       </td>
       <td class="singleborder" align='center'>
           <b><xsl:value-of select="$RES_PARAMETER_NEW_TEST_CASES"/></b>    
       </td>
       </tr>
       <xsl:call-template name="tg_author_list_info"/>
    </table>
    </xsl:template>
    
    <!-- =================  print generation details info for the auth ============================ -->
    
    <xsl:template name="tg_author_details_info">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:param name="mode"/>
    <xsl:variable name="total_tclasses" 
                 select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)])"/>
    <xsl:variable name="total_tcases" 
                 select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)]/TestCaseList/TestCase)"/>

    <xsl:if test="($total_tclasses) > 0">
    
    <tr>                 				   
    	<xsl:call-template name="details_table_auth_header">
    		<xsl:with-param name="auth" select="$auth"/>
    		<xsl:with-param name="number" select="$total_tcases"/>
    		<xsl:with-param name="message" select="$RES_PARAMETER_NEW_TEST_CASES"/>    		    		
    		<xsl:with-param name="anchor" select="concat('tg_',$authid)"/>
   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
    </tr>
    
    </xsl:if>
    
    <xsl:if test="($mode = 'single') and (not($total_tclasses > 0))">
	    <tr>
	        <td align="center" colspan="3"><xsl:value-of select="$RES_PARAMETER_NO_TEST_CASES_GENERATED"/></td>
	    </tr>            
    </xsl:if>

	<tr>
    <td aligh="right" colspan="3" >
   	<table class="doubleborder" bordercolor="{$cs_bdrcolor}" aligh="center" width="100%" rules="none" cellpadding='0' cellspacing='0'>
   	<xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">80% 10% 10%</xsl:attribute>
     </xsl:if>   	
    <xsl:if test="($total_tclasses) > 0">
    <xsl:for-each select="/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)]">
    <xsl:variable name="tclass_name" select="@unitTestType"/>
    <xsl:variable name="tcases" select="count(TestCaseList/TestCase)"/>
    <xsl:variable name="clName" select="@testedType"/>
    <!-- TODO xsl:variable name="project_name" select="../@name"/-->

    <tr>
    <td>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <!-- TODO xsl:value-of select="($project_name)"/> /  -->
    <xsl:value-of select="($clName)"/> 
    <xsl:if test="string-length($tclass_name) > 0">
    / <b><xsl:value-of select="($tclass_name)"/></b>
    </xsl:if>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        [<xsl:value-of select="($tcases)"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:if test="($tcases) = 1"><xsl:value-of
        select="$RES_PARAMETER_TEST_CASE_LOWERCASE"/></xsl:if><xsl:if test="not(($tcases) = 1)"><xsl:value-of select="$RES_PARAMETER_TEST_CASES_LOWERCASE"/></xsl:if>]
        
    </td>
    </tr>
        
    </xsl:for-each>
    </xsl:if>    
    </table>
    </td>
    </tr>
    <xsl:if test="($mode = 'single') or ($mode = 'summary' and ($total_tclasses > 0))">
    <tr>
    <td colspan="3"><br/></td>
    </tr>
    </xsl:if>
    </xsl:template>
   
    <!-- =================  print generation details info for each auth ============================ -->
    
    <xsl:template name="tg_details_info">
        <xsl:for-each select="/ResultsSession/Authors/Author">
        
            <xsl:call-template name="tg_author_details_info">
                <xsl:with-param name="auth" select="@name"/>
                <xsl:with-param name="authid" select="@id"/>
                <xsl:with-param name="mode">summary</xsl:with-param>
            </xsl:call-template>
            
       </xsl:for-each>        
    </xsl:template>    
    
</xsl:stylesheet>
